# Changelog

## [0.2.10a1](https://github.com/OpenVoiceOS/ovos-PHAL/tree/0.2.10a1) (2025-06-16)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-PHAL/compare/0.2.9...0.2.10a1)

**Closed issues:**

- Zombie ps process [\#30](https://github.com/OpenVoiceOS/ovos-PHAL/issues/30)

**Merged pull requests:**

- Update ovos-config requirement from \<2.0.0,\>=0.0.12 to \>=0.0.12,\<3.0.0 in /requirements [\#61](https://github.com/OpenVoiceOS/ovos-PHAL/pull/61) ([dependabot[bot]](https://github.com/apps/dependabot))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
